@@ -1,5 +1,6 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 from .sia import search as imagesearch
+from .sia2 import search as imagesearch2
 from .ssa import search as spectrumsearch
 from .sla import search as linesearch
 from .scs import search as conesearch
@@ -13,13 +14,14 @@ from .sla import SLAService, SLAQuery, SLAResults, SLARecord
 from .scs import SCSService, SCSQuery, SCSResults, SCSRecord
 from .tap import TAPService, TAPQuery, TAPResults, AsyncTAPJob
 
+
 from .exceptions import (
     DALAccessError, DALProtocolError, DALFormatError, DALServiceError,
     DALQueryError)
 
 __all__ = [
     "imagesearch", "spectrumsearch", "linesearch", "conesearch", "tablesearch",
-    "DALService",
+    "DALService", "sia2", "imagesearch2",
     "SIAService", "SSAService", "SLAService", "SCSService", "TAPService",
     "DALQuery",  "SIAQuery", "SSAQuery", "SLAQuery", "SCSQuery", "TAPQuery",
     "DALResults",
