@@ -34,7 +34,7 @@ import collections
 
 from warnings import warn
 
-from astropy.table.table import Table
+from astropy.table import Table
 from astropy.io.votable import parse as votableparse
 from astropy.io.votable.ucd import parse_ucd
 from astropy.utils.exceptions import AstropyDeprecationWarning
