@@ -28,14 +28,10 @@ URL.
 The ``SIAService`` class can represent a specific service available at a URL
 endpoint.
 """
-from __future__ import (
-    absolute_import, division, print_function, unicode_literals)
-
 import re
 
 from pyvo.io.vosi.vodataservice import TableParam
 
-import six
 from astropy.coordinates import SkyCoord
 from astropy.time import Time
 from astropy.units import Quantity, Unit
@@ -124,7 +120,7 @@ class SIAService(DALService):
     a representation of an SIA service
     """
 
-    def __init__(self, baseurl):
+    def __init__(self, baseurl, session=None):
         """
         instantiate an SIA service
 
@@ -132,8 +128,10 @@ class SIAService(DALService):
         ----------
         baseurl : str
            the base URL for submitting search queries to the service.
+        session : object
+           optional session to use for network requests
         """
-        super(SIAService, self).__init__(baseurl)
+        super().__init__(baseurl, session=session)
 
     def _get_metadata(self):
         """
@@ -317,7 +315,7 @@ class SIAService(DALService):
         SIAQuery
         """
         return SIAQuery(
-            self.baseurl, pos, size, format, intersect, verbosity, **keywords)
+            self.baseurl, pos, size, format, intersect, verbosity, self._session, **keywords)
 
     def describe(self):
         print(self.description)
@@ -346,7 +344,7 @@ class SIAQuery(DALQuery):
 
     def __init__(
             self, baseurl, pos=None, size=None, format=None, intersect=None,
-            verbosity=None, **keywords):
+            verbosity=None, session=None, **keywords):
         """
         initialize the query object with a baseurl and the given parameters
 
@@ -388,18 +386,20 @@ class SIAQuery(DALQuery):
             an integer value that indicates the volume of columns
             to return in the result table.  0 means the minimum
             set of columsn, 3 means as many columns as are  available.
+        session : object
+           optional session to use for network requests
         **keywords :
             additional parameters can be given via arbitrary
             case insensitive keyword arguments. Where there is overlap
             with the parameters set by the other arguments to
             this function, these keywords will override.
         """
-        super(SIAQuery, self).__init__(baseurl, **keywords)
+        super().__init__(baseurl, session=session, **keywords)
 
         if pos:
             self.pos = pos
 
-        if size:
+        if size is not None:
             self.size = size
 
         if format:
@@ -501,7 +501,7 @@ class SIAQuery(DALQuery):
     def format(self, format_):
         setattr(self, "_format", format_)
 
-        if type(format_) in (six.text_type, six.binary_type):
+        if type(format_) in (str, bytes):
             format_ = [format_]
 
         self["FORMAT"] = ",".join(_.upper() for _ in format_)
@@ -569,7 +569,7 @@ class SIAQuery(DALQuery):
         DALFormatError
            for errors parsing the VOTable response
         """
-        return SIAResults(self.execute_votable(), url=self.queryurl)
+        return SIAResults(self.execute_votable(), url=self.queryurl, session=self._session)
 
 
 class SIAResults(DatalinkResultsMixin, DALResults):
@@ -647,7 +647,7 @@ class SIAResults(DatalinkResultsMixin, DALResults):
         --------
         Record
         """
-        return SIARecord(self, index)
+        return SIARecord(self, index, session=self._session)
 
 
 class SIARecord(SodaRecordMixin, DatalinkRecordMixin, Record):
@@ -881,7 +881,7 @@ class SIARecord(SodaRecordMixin, DatalinkRecordMixin, Record):
         to retrieve the dataset described by this record.  None is returned
         if no such column exists.
         """
-        dataurl = super(SIARecord, self).getdataurl()
+        dataurl = super().getdataurl()
         if dataurl is None:
             return self.acref
         else:
@@ -896,7 +896,7 @@ class SIARecord(SodaRecordMixin, DatalinkRecordMixin, Record):
         ``make_dataset_filename()``.
         """
         out = self.title
-        if type(out) == six.binary_type:
+        if type(out) == bytes:
             out = out.decode('utf-8')
 
         if not out:
