@@ -8,6 +8,7 @@ from time import sleep
 from distutils.version import LooseVersion
 
 import requests
+from urllib.parse import urlparse, urljoin
 
 from astropy.io.votable import parse as votableparse
 
@@ -22,6 +23,8 @@ from ..io.vosi import tapregext as tr
 
 from ..utils.formatting import para_format_desc
 from ..utils.http import use_session
+import xml.etree.ElementTree
+import io
 
 __all__ = [
     "search", "escape", "TAPService", "TAPQuery", "AsyncTAPJob", "TAPResults"]
@@ -94,6 +97,7 @@ class TAPService(DALService, AvailabilityMixin, CapabilityMixin):
     """
 
     _tables = None
+    _examples = None
 
     def __init__(self, baseurl, session=None):
         """
@@ -137,6 +141,33 @@ class TAPService(DALService, AvailabilityMixin, CapabilityMixin):
                 vosi.parse_tables(response.raw.read), tables_url)
         return self._tables
 
+    @property
+    def examples(self):
+        """
+        returns examples as a list of TAPQuery objects
+        """
+        if self._examples is None:
+            examples_url = '{}/examples'.format(self.baseurl)
+
+            response = self._session.get(examples_url, stream=True)
+            if response.status_code == 404:
+                return []
+
+            try:
+                response.raise_for_status()
+            except requests.RequestException as ex:
+                raise DALServiceError.from_except(ex, examples_url)
+
+            try:
+                root = xml.etree.ElementTree.parse(io.BytesIO(response.content)).getroot()
+                exampleElements = root.findall('.//*[@property="query"]')
+            except Exception as ex:
+                raise DALServiceError.from_except(ex, examples_url)
+
+            self._examples = [TAPQuery(self.baseurl, example.text) for example in exampleElements]
+
+        return self._examples
+
     @property
     def maxrec(self):
         """
@@ -688,7 +719,10 @@ class AsyncTAPJob:
         the uri of the result
         """
         try:
-            return self.result.href
+            uri = self.result.href
+            if not urlparse(uri).netloc:
+                uri = urljoin(self.url, uri)
+            return uri
         except IndexError:
             return None
 
@@ -872,7 +906,7 @@ class TAPQuery(DALQuery):
     def queryurl(self):
         return '{baseurl}/{mode}'.format(baseurl=self.baseurl, mode=self._mode)
 
-    def execute_stream(self):
+    def execute_stream(self, post=False):
         """
         submit the query and return the raw VOTable XML as a file stream
 
@@ -889,7 +923,7 @@ class TAPQuery(DALQuery):
             raise DALServiceError(
                 "Cannot execute a non-synchronous query. Use submit instead")
 
-        return super().execute_stream()
+        return super().execute_stream(post=post)
 
     def execute(self):
         """
@@ -907,7 +941,7 @@ class TAPQuery(DALQuery):
         """
         return TAPResults(self.execute_votable(), url=self.queryurl, session=self._session)
 
-    def submit(self):
+    def submit(self, post=False):
         """
         Does the request part of the TAP query.
         This function is separated from response parsing because async queries
