@@ -4,11 +4,7 @@ This file contains a contains the high-level functions to read the various
 VOSI Endpoints.
 """
 
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
-
-import six
-
+from astropy.utils import minversion
 from astropy.utils.xml import iterparser
 from astropy.utils.collections import HomogeneousList
 from astropy.io.votable.exceptions import vo_raise, vo_warn
@@ -17,7 +13,6 @@ from astropy.io.votable.util import version_compare
 from ...utils.xml.elements import xmlattribute, xmlelement, Element
 from . import voresource as vr
 from . import vodataservice as vs
-from . import tapregext as tr
 from . import availability as av
 from .exceptions import W15, W16, E07, E10
 
@@ -25,6 +20,37 @@ __all__ = [
     "parse_tables", "parse_capabilities", "parse_availability",
     "TablesFile", "CapabilitiesFile", "AvailabilityFile"]
 
+ASTROPY_GT_4 = minversion('astropy', '4.0')
+
+
+def _pedantic_settings(pedantic):
+    """
+    Controls the pedantic parser settings.  Based on the bool
+    passed in to pedantic, create a config to be passed to
+    astropy parsing to raise exceptions or ignore them on
+    pedantic errors.
+
+    Parameters
+    ----------
+    pedantic : bool
+        When `True`, raise an error when the file violates the spec,
+        otherwise issue a warning.  Warnings may be controlled using
+        the standard Python mechanisms.  See the `warnings`
+        module in the Python standard library for more information.
+
+    Returns
+    -------
+    A dict containing configuration settings for astropy, which for
+    version 4.0 and after use 'verify', and previously use 'pedantic'.
+    """
+    if ASTROPY_GT_4:
+        if pedantic:
+            return {'verify': 'exception'}
+        else:
+            return {'verify': 'warn'}
+    else:
+        return {'pedantic': pedantic}
+
 
 def parse_tables(source, pedantic=None, filename=None,
                  _debug_python_based_parser=False):
@@ -57,13 +83,12 @@ def parse_tables(source, pedantic=None, filename=None,
     --------
     pyvo.io.vosi.exceptions : The exceptions this function may raise.
     """
-    config = {
-        'pedantic': pedantic,
-        'filename': filename
-    }
+    config = _pedantic_settings(pedantic)
 
-    if filename is None and isinstance(source, six.string_types):
+    if filename is None and isinstance(source, str):
         config['filename'] = source
+    else:
+        config['filename'] = filename
 
     with iterparser.get_xml_iterator(
         source,
@@ -104,13 +129,12 @@ def parse_capabilities(source, pedantic=None, filename=None,
     --------
     pyvo.io.vosi.exceptions : The exceptions this function may raise.
     """
-    config = {
-        'pedantic': pedantic,
-        'filename': filename
-    }
+    config = _pedantic_settings(pedantic)
 
-    if filename is None and isinstance(source, six.string_types):
+    if filename is None and isinstance(source, str):
         config['filename'] = source
+    else:
+        config['filename'] = filename
 
     with iterparser.get_xml_iterator(
         source,
@@ -151,13 +175,12 @@ def parse_availability(source, pedantic=None, filename=None,
     --------
     pyvo.io.vosi.exceptions : The exceptions this function may raise.
     """
-    config = {
-        'pedantic': pedantic,
-        'filename': filename
-    }
+    config = _pedantic_settings(pedantic)
 
-    if filename is None and isinstance(source, six.string_types):
+    if filename is None and isinstance(source, str):
         config['filename'] = source
+    else:
+        config['filename'] = filename
 
     with iterparser.get_xml_iterator(
         source,
@@ -195,7 +218,7 @@ class TablesFile(Element):
         elif self.tableset:
             return repr(self.tableset)
         else:
-            return super(TablesFile, self).__repr__()
+            return super().__repr__()
 
     @xmlattribute
     def version(self):
@@ -248,7 +271,7 @@ class TablesFile(Element):
         return self._ntables
 
     def parse(self, iterator, config):
-        super(TablesFile, self).parse(iterator, config)
+        super().parse(iterator, config)
 
         if self.tableset is None and self.table is None:
             vo_raise(E07, config=config, pos=self._pos)
@@ -276,8 +299,7 @@ class TablesFile(Element):
             yield self.table
         else:
             for schema in self.tableset.schemas:
-                for table in schema.tables:
-                    yield table
+                yield from schema.tables
 
     def get_first_table(self):
         """
@@ -330,7 +352,7 @@ class CapabilitiesFile(Element, HomogeneousList):
             else:
                 vo_raise(E10, config=config, pos=pos)
 
-        super(CapabilitiesFile, self).parse(iterator, config)
+        super().parse(iterator, config)
 
         return self
 
@@ -349,6 +371,6 @@ class AvailabilityFile(av.Availability):
                 elif tag == 'availability':
                     break
 
-        super(AvailabilityFile, self).parse(iterator, config)
+        super().parse(iterator, config)
 
         return self
