@@ -311,7 +311,10 @@ class Table(Element):
 
     def describe(self):
         print(self.name)
-        print(indent(self.description))
+        if self.description is not None:
+            print(indent(self.description))
+        else:
+            print('No description')
 
         print()
 
@@ -711,7 +714,7 @@ class DataType(ContentMixin, Element):
 
     def __repr__(self):
         return '<DataType arraysize={}>{}</DataType>'.format(
-            self.arraysize, self.value)
+            self.arraysize, self.content)
 
     @xmlattribute
     def arraysize(self):
