@@ -8,6 +8,7 @@ from urllib.parse import parse_qsl
 import pytest
 
 from pyvo.registry import search as regsearch
+from pyvo.dal import query as dalq
 
 from astropy.utils.data import get_pkg_data_contents
 
@@ -56,6 +57,31 @@ def keywords_fixture(mocker):
         yield matcher
 
 
+@pytest.fixture()
+def single_keyword_fixture(mocker):
+    def keywordstest_callback(request, context):
+        data = dict(parse_qsl(request.body))
+        query = data['QUERY']
+
+        assert "WHERE isub0.res_subject ILIKE '%single%'" in query
+        assert "WHERE 1=ivo_hasword(ires0.res_description, 'single')" in query
+        assert "OR 1=ivo_hasword(ires0.res_title, 'single')" in query
+
+        assert "'ivo://ivoa.net/std/conesearch'" in query
+        assert "'ivo://ivoa.net/std/sia'" in query
+        assert "'ivo://ivoa.net/std/ssa'" in query
+        assert "'ivo://ivoa.net/std/slap'" in query
+        assert "'ivo://ivoa.net/std/tap'" in query
+
+        return get_pkg_data_contents('data/regtap.xml')
+
+    with mocker.register_uri(
+        'POST', 'http://dc.g-vo.org/tap/sync',
+        content=keywordstest_callback
+    ) as matcher:
+        yield matcher
+
+
 @pytest.fixture()
 def servicetype_fixture(mocker):
     def servicetypetest_callback(request, context):
@@ -114,14 +140,37 @@ def datamodel_fixture(mocker):
         yield matcher
 
 
+@pytest.fixture()
+def aux_fixture(mocker):
+    def auxtest_callback(request, context):
+        data = dict(parse_qsl(request.body))
+        query = data['QUERY']
+
+        assert "ivo://ivoa.net/std/tap#aux" in query
+
+        return get_pkg_data_contents('data/regtap.xml')
+
+    with mocker.register_uri(
+        'POST', 'http://dc.g-vo.org/tap/sync',
+        content=auxtest_callback
+    ) as matcher:
+        yield matcher
+
+
 @pytest.mark.usefixtures('keywords_fixture', 'capabilities')
 def test_keywords():
     regsearch(keywords=['vizier', 'pulsar'])
 
 
+@pytest.mark.usefixtures('single_keyword_fixture', 'capabilities')
+def test_single_keyword():
+    regsearch(keywords=['single'])
+    regsearch(keywords='single')
+
+
 @pytest.mark.usefixtures('servicetype_fixture', 'capabilities')
 def test_servicetype():
-    regsearch(servicetype='tap')
+    regsearch(servicetype='table')
 
 
 @pytest.mark.usefixtures('waveband_fixture', 'capabilities')
@@ -132,3 +181,19 @@ def test_waveband():
 @pytest.mark.usefixtures('datamodel_fixture', 'capabilities')
 def test_datamodel():
     regsearch(datamodel='tap')
+
+
+@pytest.mark.usefixtures('aux_fixture', 'capabilities')
+def test_servicetype_aux():
+    regsearch(servicetype='table', includeaux=True)
+
+
+@pytest.mark.usefixtures('aux_fixture', 'capabilities')
+def test_keyword_aux():
+    regsearch(keywords=['pulsar'], includeaux=True)
+
+
+@pytest.mark.usefixtures('aux_fixture', 'capabilities')
+def test_bad_servicetype_aux():
+    with pytest.raises(dalq.DALQueryError):
+        regsearch(servicetype='bad_servicetype', includeaux=True)
